from rest_framework.pagination import PageNumberPagination
from rest_framework.response import Response


class CustomPagination(PageNumberPagination):
    page_size = 10  # Default page size
    page_size_query_param = "page_size"  # Allow client to set page size
    max_page_size = 200  # Maximum page size allowed

    def get_paginated_response(self, data):
        return Response(
            {
                "links": {
                    "previous": self.get_previous_link(),
                    "next": self.get_next_link(),
                },
                "total_items": self.page.paginator.count,
                "total_pages": self.page.paginator.num_pages,
                "page_size": self.page.paginator.per_page,
                "current_page": self.page.number,
                "results": data,
            }
        )

    def get_paginated_response_schema(self, schema):
        return {
            "type": "object",
            "properties": {
                "links": {
                    "type": "object",
                    "properties": {
                        "previous": {
                            "type": ["string", "null"],
                            "format": "uri",
                            "example": "http://api.example.org/accounts/?page=2",
                        },
                        "next": {
                            "type": ["string", "null"],
                            "format": "uri",
                            "example": "http://api.example.org/accounts/?page=4",
                        },
                    },
                    "required": ["previous", "next"],
                },
                "total_items": {
                    "type": "integer",
                    "example": 100,
                },
                "total_pages": {
                    "type": "integer",
                    "example": 10,
                },
                "page_size": {
                    "type": "integer",
                    "example": 10,
                },
                "current_page": {
                    "type": "integer",
                    "example": 1,
                },
                "results": schema,  # Shema natijalar uchun ishlatiladi
            },
            "required": [
                "links",
                "total_items",
                "total_pages",
                "page_size",
                "current_page",
                "results",
            ],
        }



def dashboard_callback(request, context):
    context.update(
        {
            "cards": (
                {
                    "color": "blue",
                    "value": 10000,
                    "title": "Shartnomalar",
                },
                {
                    "color": "primary",
                    "value": 10000,
                    "title": "Tugallangan",
                },
                {
                    "color": "orange",
                    "value": 10000,
                    "title": "Kutilmoqda",
                },
                {
                    "color": "red",
                    "value": 10000,
                    "title": "Bekor qilingan",
                },
                {
                    "color": "green",
                    "value": 10000,
                    "title": "Bajarilmoqda",
                },
                {
                    "color": "red",
                    "value": "{:,} so'm".format(10000),
                    "title": "Qarizlar",
                },
                {
                    "color": "green",
                    "value": "{:,} so'm".format(10000),
                    "title": "To'langan",
                },
                {
                    "color": "green",
                    "value": "{:,} so'm".format(10000),
                    "title": "Jami summa",
                },
            ),
        }
    )

    return context



import json

from django.conf import settings
import os
from django.templatetags import static
from django.utils import safestring

from django import template

register = template.Library()


def getScript(url: object) -> str:
    ext: str = str(url).split(".")[-1]

    if os.getenv("VITE_LIVE", False):
        url = f"http://{os.getenv('VITE_HOST', "0.0.0.0")}:{os.getenv('VITE_PORT', 5000)}/{url}"
    else:
        url = static.static(f"vite/{url}")

    if ext == "css":
        script = f"<link rel='stylesheet' type='text/css' href='{url}'>"
    else:
        script = (
            "<script type='module' type='text/javascript' src='{" "}'></script>"
        ).format(url)
    return script


@register.simple_tag
def vite_load(*args):
    try:
        fd = open(f"{settings.VITE_APP_DIR}/manifest.json")
        manifest = json.load(fd)
    except Exception:
        raise Exception(
            f"Vite manifest file not found or invalid. Maybe your"
            f" {settings.VITE_APP_DIR}/manifest.json file is empty?"
        )
    if not os.getenv("VITE_LIVE", False):
        imports_files = "".join([getScript(file["file"]) for file in manifest.values()])

    else:
        imports_files = "".join([getScript(file) for file in args])
        imports_files += f""" <script type="module" src="http://{os.getenv('VITE_HOST', "0.0.0.0")}:{os.getenv('VITE_PORT', 5000)}/@vite/client">
        </script> <script type="module" src="{static.static("js/vite-refresh.js")}"></script>"""

    return safestring.mark_safe(imports_files)
